@@ -20,7 +20,10 @@ for conditions of use.
 #include "netcdf_par.h"
 #endif
 #include "netcdf.h"
-#include "err_macros.h"
+//#include "err_macros.h"
+
+
+#define NC_TESTS_MAX_DIMS 1024 /**< NC_MAX_DIMS for tests.  Allows different NC_MAX_DIMS values without breaking this test with a heap or stack overflow. */
 
 /** Useful define for tests. */
 /** \{ */
