@@ -2,7 +2,7 @@
    Copyright 2005 University Corporation for Atmospheric Research/Unidata
    See COPYRIGHT file for conditions of use.
 
-   Test netcdf-4 compound type feature. 
+   Test netcdf-4 compound type feature.
 
    $Id: tst_compounds.c,v 1.45 2010/05/25 13:53:03 ed Exp $
 */
@@ -10,6 +10,7 @@
 #include <config.h>
 #include <stdlib.h>
 #include <nc_tests.h>
+#include "err_macros.h"
 
 #define FILE_NAME "tst_compounds.nc"
 #define SVC_REC "Service_Record"
@@ -33,16 +34,16 @@ main(int argc, char **argv)
       size_t size;
       nc_type xtype, field_xtype;
       int dimids[] = {0}, fieldid;
-      int field_ndims, field_sizes[NC_MAX_DIMS];
+      int field_ndims, field_sizes[NC_TESTS_MAX_DIMS];
       size_t offset;
-      struct s1 
+      struct s1
       {
 	    int i1;
 	    int i2;
       };
       struct s1 data, data_in;
 
-      /* Create some phony data. */   
+      /* Create some phony data. */
       data.i1 = 5;
       data.i2 = 10;
 
@@ -51,9 +52,9 @@ main(int argc, char **argv)
       if (nc_def_compound(ncid, sizeof(struct s1), SVC_REC, &typeid)) ERR;
       if (nc_inq_compound(ncid, typeid, name, &size, &nfields)) ERR;
       if (size != sizeof(struct s1) || strcmp(name, SVC_REC) || nfields) ERR;
-      if (nc_insert_compound(ncid, typeid, BATTLES_WITH_KLINGONS, 
+      if (nc_insert_compound(ncid, typeid, BATTLES_WITH_KLINGONS,
 			     NC_COMPOUND_OFFSET(struct s1, i1), NC_INT)) ERR;
-      if (nc_insert_compound(ncid, typeid, DATES_WITH_ALIENS, 
+      if (nc_insert_compound(ncid, typeid, DATES_WITH_ALIENS,
 			     NC_COMPOUND_OFFSET(struct s1, i2), NC_INT)) ERR;
       if (nc_def_var(ncid, SERVICE_RECORD, typeid, 0, NULL, &varid)) ERR;
       if (nc_put_var(ncid, varid, &data)) ERR;
@@ -106,10 +107,10 @@ main(int argc, char **argv)
       size_t size;
       nc_type xtype, field_xtype;
       int dimids[] = {0}, fieldid;
-      int field_ndims, field_sizes[NC_MAX_DIMS];
+      int field_ndims, field_sizes[NC_TESTS_MAX_DIMS];
       size_t offset;
       int i;
-      struct s1 
+      struct s1
       {
 	    int i1;
 	    int i2;
@@ -119,12 +120,12 @@ main(int argc, char **argv)
 
       /* REALLY initialize the data (even the gaps in the structs). This
        * is only needed to pass valgrind. */
-      if (!(dummy = calloc(sizeof(struct s1), DIM_LEN))) 
-	 return NC_ENOMEM; 
-      memcpy((void *)data, (void *)dummy, sizeof(struct s1) * DIM_LEN); 
-      free(dummy); 
+      if (!(dummy = calloc(sizeof(struct s1), DIM_LEN)))
+	 return NC_ENOMEM;
+      memcpy((void *)data, (void *)dummy, sizeof(struct s1) * DIM_LEN);
+      free(dummy);
 
-      /* Create some phony data. */   
+      /* Create some phony data. */
       for (i = 0; i < DIM_LEN; i++)
       {
 	 data[i].i1 = 5;
@@ -136,9 +137,9 @@ main(int argc, char **argv)
       if (nc_def_compound(ncid, sizeof(struct s1), SVC_REC, &typeid)) ERR;
       if (nc_inq_compound(ncid, typeid, name, &size, &nfields)) ERR;
       if (size != sizeof(struct s1) || strcmp(name, SVC_REC) || nfields) ERR;
-      if (nc_insert_compound(ncid, typeid, BATTLES_WITH_KLINGONS, 
+      if (nc_insert_compound(ncid, typeid, BATTLES_WITH_KLINGONS,
 			     NC_COMPOUND_OFFSET(struct s1, i1), NC_INT)) ERR;
-      if (nc_insert_compound(ncid, typeid, DATES_WITH_ALIENS, 
+      if (nc_insert_compound(ncid, typeid, DATES_WITH_ALIENS,
 			     NC_COMPOUND_OFFSET(struct s1, i2), NC_INT)) ERR;
       if (nc_def_dim(ncid, STARDATE, DIM_LEN, &dimid)) ERR;
       if (nc_def_var(ncid, SERVICE_RECORD, typeid, 1, dimids, &varid)) ERR;
@@ -204,7 +205,7 @@ main(int argc, char **argv)
         if (nc_get_vars(ncid, varid, start, edges, stride, data)) ERR;
         for (i=0; i<DIM_LEN_S; i++) {
 	  if(data[i].i1 != datas[i].i1 || data[i].i2 != datas[i].i2) ERR;
-	}	
+	}
       }
 
       if (nc_close(ncid)) ERR;
@@ -217,7 +218,7 @@ main(int argc, char **argv)
       nc_type xtype;
       size_t size_in, nfields_in;
       char name_in[NC_MAX_NAME + 1];
-      
+
       /* Create a file with a compound type. Write a little data. */
       if (nc_create(FILE_NAME, NC_NETCDF4, &ncid)) ERR;
       if (nc_def_compound(ncid, sizeof(int), SVC_REC, &typeid)) ERR;
@@ -227,8 +228,8 @@ main(int argc, char **argv)
 
       /* Open the file and take a peek. */
       if (nc_open(FILE_NAME, NC_WRITE, &ncid)) ERR;
-      if (nc_inq(ncid, &ndims, &nvars, &natts, &unlimdimid)) ERR; 
-      if (ndims != 0 || nvars != 1 || natts != 0 || unlimdimid != -1) ERR; 
+      if (nc_inq(ncid, &ndims, &nvars, &natts, &unlimdimid)) ERR;
+      if (ndims != 0 || nvars != 1 || natts != 0 || unlimdimid != -1) ERR;
       if (nc_inq_vartype(ncid, 0, &xtype)) ERR;
       if (nc_inq_compound(ncid, xtype, name_in, &size_in, &nfields_in)) ERR;
       if (strcmp(name_in, SVC_REC) || size_in != sizeof(int) || nfields_in != 1) ERR;
@@ -244,10 +245,10 @@ main(int argc, char **argv)
       size_t size, len;
       nc_type xtype, field_xtype;
       int fieldid;
-      int field_ndims, field_sizes[NC_MAX_DIMS];
+      int field_ndims, field_sizes[NC_TESTS_MAX_DIMS];
       size_t offset;
       int i;
-      struct s1 
+      struct s1
       {
 	    int i1;
 	    int i2;
@@ -257,12 +258,12 @@ main(int argc, char **argv)
 
       /* REALLY initialize the data (even the gaps in the structs). This
        * is only needed to pass valgrind. */
-      if (!(dummy = calloc(sizeof(struct s1), DIM_LEN))) 
-	 return NC_ENOMEM; 
-      memcpy((void *)data, (void *)dummy, sizeof(struct s1) * DIM_LEN); 
-      free(dummy); 
+      if (!(dummy = calloc(sizeof(struct s1), DIM_LEN)))
+	 return NC_ENOMEM;
+      memcpy((void *)data, (void *)dummy, sizeof(struct s1) * DIM_LEN);
+      free(dummy);
 
-      /* Create some phony data. */   
+      /* Create some phony data. */
       for (i=0; i<DIM_LEN; i++)
       {
 	 data[i].i1 = 5;
@@ -272,9 +273,9 @@ main(int argc, char **argv)
       /* Create a file with a global attribute of compound type. */
       if (nc_create(FILE_NAME, NC_NETCDF4, &ncid)) ERR;
       if (nc_def_compound(ncid, sizeof(struct s1), SVC_REC, &typeid)) ERR;
-      if (nc_insert_compound(ncid, typeid, BATTLES_WITH_KLINGONS, 
+      if (nc_insert_compound(ncid, typeid, BATTLES_WITH_KLINGONS,
 			     NC_COMPOUND_OFFSET(struct s1, i1), NC_INT)) ERR;
-      if (nc_insert_compound(ncid, typeid, DATES_WITH_ALIENS, 
+      if (nc_insert_compound(ncid, typeid, DATES_WITH_ALIENS,
 			     NC_COMPOUND_OFFSET(struct s1, i2), NC_INT)) ERR;
       if (nc_put_att(ncid, NC_GLOBAL, SERVICE_RECORD, typeid, 3, data)) ERR;
       if (nc_close(ncid)) ERR;
@@ -320,7 +321,7 @@ main(int argc, char **argv)
       size_t size;
       nc_type xtype, field_xtype;
       int dimids[] = {0};
-      int field_ndims, field_sizes[NC_MAX_DIMS];
+      int field_ndims, field_sizes[NC_TESTS_MAX_DIMS];
       size_t offset;
       int i;
 
@@ -338,12 +339,12 @@ main(int argc, char **argv)
 
       /* REALLY initialize the data (even the gaps in the structs). This
        * is only needed to pass valgrind. */
-      if (!(dummy = calloc(sizeof(struct sf_med_rec), DIM_LEN))) 
-	 return NC_ENOMEM; 
-      memcpy((void *)med_data_out, (void *)dummy, sizeof(struct sf_med_rec) * DIM_LEN); 
-      free(dummy); 
+      if (!(dummy = calloc(sizeof(struct sf_med_rec), DIM_LEN)))
+	 return NC_ENOMEM;
+      memcpy((void *)med_data_out, (void *)dummy, sizeof(struct sf_med_rec) * DIM_LEN);
+      free(dummy);
 
-      /* Create some phony data. */   
+      /* Create some phony data. */
       for (i=0; i<DIM_LEN; i++)
       {
 	 /* medical data */
@@ -357,15 +358,15 @@ main(int argc, char **argv)
       /* Create a file with a compound type. Write a little data. */
       if (nc_create(FILE_NAME, NC_NETCDF4, &ncid)) ERR;
       if (nc_def_compound(ncid, sizeof(struct sf_med_rec), "SFMedRec", &typeid)) ERR;
-      if (nc_insert_compound(ncid, typeid, "num_heads", 
+      if (nc_insert_compound(ncid, typeid, "num_heads",
 			     NC_COMPOUND_OFFSET(struct sf_med_rec, num_heads), NC_UBYTE)) ERR;
-      if (nc_insert_compound(ncid, typeid, "num_arms", 
+      if (nc_insert_compound(ncid, typeid, "num_arms",
 			     NC_COMPOUND_OFFSET(struct sf_med_rec, num_arms), NC_USHORT)) ERR;
-      if (nc_insert_compound(ncid, typeid, "num_toes", 
+      if (nc_insert_compound(ncid, typeid, "num_toes",
 			     NC_COMPOUND_OFFSET(struct sf_med_rec, num_toes), NC_UINT)) ERR;
-      if (nc_insert_compound(ncid, typeid, "ago", 
+      if (nc_insert_compound(ncid, typeid, "ago",
 			     NC_COMPOUND_OFFSET(struct sf_med_rec, ago), NC_INT64)) ERR;
-      if (nc_insert_compound(ncid, typeid, "num_hairs", 
+      if (nc_insert_compound(ncid, typeid, "num_hairs",
 			     NC_COMPOUND_OFFSET(struct sf_med_rec, num_hairs), NC_UINT64)) ERR;
       if (nc_def_dim(ncid, STARDATE, DIM_LEN, &dimid)) ERR;
       if (nc_def_var(ncid, "starbase_13", typeid, 1, dimids, &varid)) ERR;
@@ -382,20 +383,20 @@ main(int argc, char **argv)
 	 if (nc_inq_compound_field(ncid, xtype, 0, name, &offset, &field_xtype, &field_ndims, field_sizes)) ERR;
 	 if (strcmp(name, "num_heads") || offset != 0 || field_xtype != NC_UBYTE) ERR;
 	 if (nc_inq_compound_field(ncid, xtype, 1, name, &offset, &field_xtype, &field_ndims, field_sizes)) ERR;
-	 if (strcmp(name, "num_arms") || offset != NC_COMPOUND_OFFSET(struct sf_med_rec, num_arms) || 
+	 if (strcmp(name, "num_arms") || offset != NC_COMPOUND_OFFSET(struct sf_med_rec, num_arms) ||
 	     field_xtype != NC_USHORT) ERR;
 	 if (nc_inq_compound_field(ncid, xtype, 2, name, &offset, &field_xtype, &field_ndims, field_sizes)) ERR;
-	 if (strcmp(name, "num_toes") || offset != NC_COMPOUND_OFFSET(struct sf_med_rec, num_toes) || 
+	 if (strcmp(name, "num_toes") || offset != NC_COMPOUND_OFFSET(struct sf_med_rec, num_toes) ||
 	     field_xtype != NC_UINT) ERR;
 	 if (nc_inq_compound_field(ncid, xtype, 3, name, &offset, &field_xtype, &field_ndims, field_sizes)) ERR;
-	 if (strcmp(name, "ago") || offset != NC_COMPOUND_OFFSET(struct sf_med_rec, ago) || 
+	 if (strcmp(name, "ago") || offset != NC_COMPOUND_OFFSET(struct sf_med_rec, ago) ||
 	     field_xtype != NC_INT64) ERR;
 	 if (nc_inq_compound_field(ncid, xtype, 4, name, &offset, &field_xtype, &field_ndims, field_sizes)) ERR;
-	 if (strcmp(name, "num_hairs") || offset != NC_COMPOUND_OFFSET(struct sf_med_rec, num_hairs) || 
+	 if (strcmp(name, "num_hairs") || offset != NC_COMPOUND_OFFSET(struct sf_med_rec, num_hairs) ||
 	     field_xtype != NC_UINT64) ERR;
 	 if (nc_get_var(ncid, varid, med_data_in)) ERR;
 	 for (i=0; i<DIM_LEN; i++)
-	    if (med_data_in[i].num_heads != med_data_out[i].num_heads || 
+	    if (med_data_in[i].num_heads != med_data_out[i].num_heads ||
 		med_data_in[i].num_arms != med_data_out[i].num_arms ||
 		med_data_in[i].num_toes != med_data_out[i].num_toes ||
 		med_data_in[i].ago != med_data_out[i].ago ||
@@ -417,7 +418,7 @@ main(int argc, char **argv)
       size_t size;
       nc_type xtype;
       int dimids[] = {0};
-      int field_ndims, field_sizes[NC_MAX_DIMS];
+      int field_ndims, field_sizes[NC_TESTS_MAX_DIMS];
       size_t offset;
       nc_type field_typeid;
       int dim_sizes[] = {NUM_DIMENSIONS};
@@ -495,7 +496,7 @@ main(int argc, char **argv)
       char name[NC_MAX_NAME + 1];
       size_t size, len;
       nc_type xtype, field_xtype;
-      int field_ndims, field_sizes[NC_MAX_DIMS];
+      int field_ndims, field_sizes[NC_TESTS_MAX_DIMS];
       size_t offset;
       nc_type svc_recid, hr_recid;
       int dim_sizes[] = {NC_MAX_NAME + 1};
@@ -589,7 +590,7 @@ main(int argc, char **argv)
 	     hr_data_in[i].percent_transporter_errosion !=
 	     hr_data_out[i].percent_transporter_errosion) ERR;
       }
-      
+
       /* Use the inq functions to learn about nested compound type. */
       if (nc_inq_att(ncid, NC_GLOBAL, "HR_Records", &xtype, &len)) ERR;
       if (len != DIM_LEN) ERR;
@@ -600,7 +601,7 @@ main(int argc, char **argv)
       if (nc_inq_compound_field(ncid, xtype, 1, name, &offset, &field_xtype, &field_ndims, field_sizes)) ERR;
       if (strcmp(name, "Service_Record") || offset != NC_COMPOUND_OFFSET(struct hr_rec, svc_rec)) ERR;
       /* Check the internal compound type. */
-      
+
       /* Finish checking the containing compound type. */
       if (nc_close(ncid)) ERR;
    }
@@ -697,7 +698,7 @@ main(int argc, char **argv)
       if (nc_close(ncid)) ERR;
 
       /* Check it out. */
-   
+
       /* Reopen the file. */
       if (nc_open(FILE_NAME, NC_NOWRITE, &ncid)) ERR;
 
@@ -737,7 +738,7 @@ main(int argc, char **argv)
 	 if (val_in.relhum != obsdata[i].relhum) ERR;
 	 if (val_in.time != obsdata[i].time) ERR;
       }
-   
+
       if (nc_close(ncid)) ERR;
 
    }
@@ -772,7 +773,7 @@ main(int argc, char **argv)
       nc_type class_in;
       int ntypes;
       char file_in[NC_MAX_NAME * 2];
-      
+
       if (getenv("srcdir"))
       {
 	 strcpy(file_in, getenv("srcdir"));
@@ -820,7 +821,7 @@ main(int argc, char **argv)
 	 if (val_in.relhum != obsdata[i].relhum) ERR;
 	 if (val_in.time != obsdata[i].time) ERR;
       }
-   
+
       if (nc_close(ncid)) ERR;
    }
 
@@ -847,10 +848,10 @@ main(int argc, char **argv)
 
       /* REALLY initialize the data (even the gaps in the structs). This
        * is only needed to pass valgrind. */
-      if (!(dummy = calloc(sizeof(struct hr_rec), DIM1_LEN))) 
-	 return NC_ENOMEM; 
-      memcpy((void *)hr_data_out, (void *)dummy, sizeof(struct hr_rec) * DIM1_LEN); 
-      free(dummy); 
+      if (!(dummy = calloc(sizeof(struct hr_rec), DIM1_LEN)))
+	 return NC_ENOMEM;
+      memcpy((void *)hr_data_out, (void *)dummy, sizeof(struct hr_rec) * DIM1_LEN);
+      free(dummy);
 
       /* Create some phony data. */
       for (i = 0; i < DIM1_LEN; i++)
@@ -880,11 +881,11 @@ main(int argc, char **argv)
       for (i=0; i<DIM1_LEN; i++)
 	 if (strcmp(hr_data_in[i].name, hr_data_out[i].name) ||
 	     hr_data_in[i].max_temp != hr_data_out[i].max_temp) ERR;
-      
+
       /* Use the inq functions to learn about the compound type. */
       if (nc_inq_att(ncid, NC_GLOBAL, "HR_Records", &xtype, &len)) ERR;
       if (len != DIM1_LEN) ERR;
-      
+
       /* Finish checking the containing compound type. */
       if (nc_close(ncid)) ERR;
    }
@@ -912,10 +913,10 @@ main(int argc, char **argv)
 
       /* REALLY initialize the data (even the gaps in the structs). This
        * is only needed to pass valgrind. */
-      if (!(dummy = calloc(sizeof(struct hr_rec), DIM1_LEN))) 
-	 return NC_ENOMEM; 
-      memcpy((void *)hr_data_out, (void *)dummy, sizeof(struct hr_rec) * DIM1_LEN); 
-      free(dummy); 
+      if (!(dummy = calloc(sizeof(struct hr_rec), DIM1_LEN)))
+	 return NC_ENOMEM;
+      memcpy((void *)hr_data_out, (void *)dummy, sizeof(struct hr_rec) * DIM1_LEN);
+      free(dummy);
 
       /* Create some phony data. */
       for (i = 0; i < DIM1_LEN; i++)
@@ -949,11 +950,11 @@ main(int argc, char **argv)
 	 for (j = 0; j < ARRAY_LEN; j++)
 	    if (hr_data_in[i].name[j] != hr_data_out[i].name[j]) ERR;
       }
-      
+
       /* Use the inq functions to learn about the compound type. */
       if (nc_inq_att(ncid, NC_GLOBAL, "HR_Records", &xtype, &len)) ERR;
       if (len != DIM1_LEN) ERR;
-      
+
       /* Finish checking the containing compound type. */
       if (nc_close(ncid)) ERR;
    }
@@ -974,10 +975,10 @@ main(int argc, char **argv)
 
       /* REALLY initialize the data (even the gaps in the structs). This
        * is only needed to pass valgrind. */
-      if (!(dummy = calloc(sizeof(struct s1), DATA_LEN))) 
-	 return NC_ENOMEM; 
-      memcpy((void *)data_out, (void *)dummy, sizeof(struct s1) * DATA_LEN); 
-      free(dummy); 
+      if (!(dummy = calloc(sizeof(struct s1), DATA_LEN)))
+	 return NC_ENOMEM;
+      memcpy((void *)data_out, (void *)dummy, sizeof(struct s1) * DATA_LEN);
+      free(dummy);
 
       /* Create some phony data. */
       for (idx = 0; idx < DATA_LEN; idx++)
@@ -1011,5 +1012,3 @@ main(int argc, char **argv)
    SUMMARIZE_ERR;
    FINAL_RESULTS;
 }
-
-
