@@ -25,10 +25,6 @@ int opterr;
 int optind;
 #endif
 
-#ifndef HAVE_SSIZE_T
-typedef int ssize_t;
-#endif
-
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
@@ -37,8 +33,8 @@ typedef int ssize_t;
 #ifdef HAVE_LOCALE_H
 #include <locale.h>
 #endif	/* HAVE_LOCALE_H */
-#include <netcdf.h>
-#include <netcdf_mem.h>
+#include "netcdf.h"
+#include "netcdf_mem.h"
 #include "utils.h"
 #include "nccomps.h"
 #include "nctime0.h"		/* new iso time and calendar stuff */
@@ -49,6 +45,15 @@ typedef int ssize_t;
 #include "isnan.h"
 #include "cdl.h"
 
+#ifdef USE_NETCDF4
+#include "nc4internal.h" /* to get name of the special properties file */
+#endif
+
+#if !defined(HAVE_SSIZE_T) && !defined(H5_SIZEOF_SSIZE_T)
+typedef int ssize_t;
+#endif
+
+#define XML_VERSION "1.0"
 
 #define int64_t long long
 #define uint64_t unsigned long long
@@ -70,7 +75,7 @@ static int iskeyword(const char* kw)
     const char** p;
     for(p=keywords;*p;p++) {
 	if(strcmp(kw,*p)==0) return 1;
-    }    
+    }
     return 0;
 }
 
@@ -115,10 +120,12 @@ usage(void)
   [-g grp1[,...]]  Data and metadata for group(s) <grp1>,... only\n\
   [-w]             With client-side caching of variables for DAP URLs\n\
   [-x]             Output XML (NcML) instead of CDL\n\
+  [-Xp]            Unconditionally suppress output of the properties attribute\n\
+  [-Ln]            Set log level to n (>= 0); ignore if logging not enabled.\n\
   file             Name of netCDF file (or URL if DAP access enabled)\n"
 
     (void) fprintf(stderr,
-		   "%s [-c|-h] [-v ...] [[-b|-f] [c|f]] [-l len] [-n name] [-p n[,n]] [-k] [-x] [-s] [-t|-i] [-g ...] [-w] file\n%s",
+		   "%s [-c|-h] [-v ...] [[-b|-f] [c|f]] [-l len] [-n name] [-p n[,n]] [-k] [-x] [-s] [-t|-i] [-g ...] [-w] [-Ln] file\n%s",
 		   progname,
 		   USAGE);
 
@@ -393,8 +400,8 @@ done:
 static void
 pr_initx(int ncid, const char *path)
 {
-    printf("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<netcdf xmlns=\"http://www.unidata.ucar.edu/namespaces/netcdf/ncml-2.2\" location=\"%s\">\n",
-	   path);
+    printf("<?xml version=\"%s\" encoding=\"UTF-8\"?>\n<netcdf xmlns=\"http://www.unidata.ucar.edu/namespaces/netcdf/ncml-2.2\" location=\"%s\">\n",
+	   XML_VERSION, path);
 }
 
 /*
@@ -472,6 +479,7 @@ pr_att_string(
  */
 static void
 pr_attx_string(
+     const char* attname,
      size_t len,
      const char *string
      )
@@ -480,6 +488,7 @@ pr_attx_string(
     const char *cp;
     const char *sp;
     unsigned char uc;
+    int nulcount = 0;
 
     cp = string;
     printf ("\"");
@@ -510,6 +519,11 @@ pr_attx_string(
 	case '\t':
 	    printf ("&#x9;");
 	    break;
+	case '\0':
+	    printf ("&#0;");
+	    if(nulcount++ == 0)
+		fprintf(stderr,"Attribute: '%s'; value contains nul characters; producing illegal xml\n",attname);
+	    break;
 	default:
 	    if (iscntrl(uc))
 	        printf ("&#%d;",uc);
@@ -749,6 +763,12 @@ pr_att(
     ncatt_t att;			/* attribute */
 
     NC_CHECK( nc_inq_attname(ncid, varid, ia, att.name) );
+#ifdef USE_NETCDF4
+    if (ncid == getrootid(ncid)
+        && varid == NC_GLOBAL
+        && strcmp(att.name,NCPROPS)==0)
+	return; /* will be printed elsewere */
+#endif
     NC_CHECK( nc_inq_att(ncid, varid, att.name, &att.type, &att.len) );
     att.tinfo = get_typeinfo(att.type);
 
@@ -773,7 +793,7 @@ pr_att(
     /* 	printf ("\t\t%s:%s = ", varname, att.name); */
     print_name(varname);
     if(iskeyword(varname)) /* see discussion about escapes in ncgen man page*/
-	printf(" ");    
+	printf(" ");
     printf(":");
     print_name(att.name);
     printf(" = ");
@@ -944,7 +964,6 @@ pr_att_global_format(
     printf (" ;\n");
 }
 
-
 #ifdef USE_NETCDF4
 /*
  * Print special reserved variable attributes, such as _Chunking,
@@ -1046,6 +1065,7 @@ pr_att_specials(
 	    printf(" = \"true\" ;\n");
 	}
     }
+
     /* TODO: handle _Nbit when inquire function is available */
 
     /* TODO: handle _ScaleOffset when inquire is available */
@@ -1054,6 +1074,57 @@ pr_att_specials(
 }
 #endif /* USE_NETCDF4 */
 
+#ifdef USE_NETCDF4
+static void
+pr_att_hidden(
+    int ncid,
+    int kind
+    )
+{
+    int stat;
+    size_t len;
+
+    /* No special variable attributes for classic or 64-bit offset data */
+    if(kind == 1 || kind == 2)
+	return;
+    /* Print out Selected hidden attributes */
+    /* NCPROPS */
+    stat = nc_inq_att(ncid,NC_GLOBAL,NCPROPS,NULL,&len);
+    if(stat == NC_NOERR) {
+	char* propdata = (char*)malloc(len+1);
+	if(propdata == NULL)
+	    return;
+        stat = nc_get_att_text(ncid,NC_GLOBAL,NCPROPS,propdata);
+        if(stat == NC_NOERR) {
+            pr_att_name(ncid, "", NCPROPS);
+            /* make sure its null terminated */
+            propdata[len] = '\0';
+            printf(" = \"%s\" ;\n",propdata);
+        }
+	free(propdata);
+    }
+    /* _SuperblockVersion */
+    stat = nc_inq_att(ncid,NC_GLOBAL,SUPERBLOCKATT,NULL,&len);
+    if(stat == NC_NOERR && len == 1) {
+        int sbversion;
+        stat = nc_get_att_int(ncid,NC_GLOBAL,SUPERBLOCKATT,&sbversion);
+        if(stat == NC_NOERR) {
+            pr_att_name(ncid, "", SUPERBLOCKATT);
+            printf(" = %d ;\n",sbversion);
+        }
+    }
+    /* _IsNetcdf4 */
+    stat = nc_inq_att(ncid,NC_GLOBAL,ISNETCDF4ATT,NULL,&len);
+    if(stat == NC_NOERR && len == 1) {
+        int isnc4;
+        stat = nc_get_att_int(ncid,NC_GLOBAL,ISNETCDF4ATT,&isnc4);
+        if(stat == NC_NOERR) {
+            pr_att_name(ncid, "", ISNETCDF4ATT);
+            printf(" = %d ;\n",isnc4?1:0);
+        }
+    }
+}
+#endif /* USE_NETCDF4 */
 
 /*
  * Print a variable attribute for NcML
@@ -1070,6 +1141,15 @@ pr_attx(
     int attvalslen = 0;
 
     NC_CHECK( nc_inq_attname(ncid, varid, ia, att.name) );
+#ifdef USE_NETCDF4
+    if (ncid == getrootid(ncid)
+	&& varid == NC_GLOBAL
+        && strcmp(att.name,NCPROPS)==0
+        && (!formatting_specs.special_atts
+            || !formatting_specs.xopt_props)
+	)
+	return;
+#endif
     NC_CHECK( nc_inq_att(ncid, varid, att.name, &att.type, &att.len) );
 
     /* Put attribute values into a single string, with blanks in between */
@@ -1120,7 +1200,7 @@ pr_attx(
 		varid != NC_GLOBAL ? "  " : "",
 		att.name);
 	/* print attvals as a string with XML escapes */
-	pr_attx_string(attvalslen, attvals);
+	pr_attx_string(att.name, attvalslen, attvals);
     } else {			/* non-string attribute */
 	char att_type_name[NC_MAX_NAME + 1];
 	get_type_name(ncid, att.type, att_type_name);
@@ -1317,8 +1397,11 @@ print_ud_type(int ncid, nc_type typeid) {
 		    printf(" ;\n");
 		}
             indent_out();
-/* 	    printf("}; // %s\n", type_name); */
+#if 0
+ 	    printf("}; // %s\n", type_name);
+#else
 	    printf("}; // ");
+#endif
 	    print_type_name(ncid, typeid);
 	    printf("\n");
 	}
@@ -1658,7 +1741,6 @@ do_ncdump_rec(int ncid, const char *path)
 #endif /* USE_NETCDF4 */
    }
 
-   /* get global attributes */
    if (ngatts > 0 || formatting_specs.special_atts) {
       printf ("\n");
       indent_out();
@@ -1672,9 +1754,14 @@ do_ncdump_rec(int ncid, const char *path)
    }
    if (is_root && formatting_specs.special_atts) { /* output special attribute
 					   * for format variant */
+#ifdef USE_NETCDF4
+       pr_att_hidden(ncid, kind);
+#endif
        pr_att_global_format(ncid, kind);
    }
 
+   fflush(stdout);
+
    /* output variable data, unless "-h" option specified header only
     * or this group is not in list of groups specified by "-g"
     * option  */
@@ -2011,6 +2098,7 @@ main(int argc, char *argv[])
     bool_t xml_out = false;    /* if true, output NcML instead of CDL */
     bool_t kind_out = false;	/* if true, just output kind of netCDF file */
     bool_t kind_out_extended = false;	/* output inq_format vs inq_format_extended */
+    int Xp_flag = 0;    /* indicate that -Xp flag was set */
 
 #if defined(WIN32) || defined(msdos) || defined(WIN64)
     putenv("PRINTF_EXPONENT_DIGITS=2"); /* Enforce unix/linux style exponent formatting. */
@@ -2031,7 +2119,7 @@ main(int argc, char *argv[])
        exit(EXIT_SUCCESS);
     }
 
-    while ((c = getopt(argc, argv, "b:cd:f:g:hikl:n:p:stv:xwKX:")) != EOF)
+    while ((c = getopt(argc, argv, "b:cd:f:g:hikl:n:p:stv:xwKL:X:")) != EOF)
       switch(c) {
 	case 'h':		/* dump header only, no data */
 	  formatting_specs.header_only = true;
@@ -2124,16 +2212,38 @@ main(int argc, char *argv[])
 	    case 'm':
 	      formatting_specs.xopt_inmemory = 1;
 	      break;
+	    case 'p': /* suppress the properties attribute */
+	      Xp_flag = 1; /* record that this flag was set */
+	      break;
 	    default:
 	      error("invalid value for -X option: %s", optarg);
 	      break;
 	  }
 	  break;
+        case 'L':
+#ifdef LOGGING
+	  {
+	  int level = atoi(optarg);
+	  if(level >= 0)
+	    nc_set_log_level(level);
+	  }
+#endif
+	  break;
         case '?':
 	  usage();
 	  exit(EXIT_FAILURE);
       }
 
+    /* Decide xopt_props */
+    if(formatting_specs.special_atts && Xp_flag == 1)
+        formatting_specs.xopt_props = 0;
+    else if(formatting_specs.special_atts && Xp_flag == 0)
+        formatting_specs.xopt_props = 1;
+    else if(!formatting_specs.special_atts)
+	formatting_specs.xopt_props = 0;
+    else
+	formatting_specs.xopt_props = 0;
+
     set_max_len(max_len);
 
     argc -= optind;
