@@ -86,7 +86,10 @@
      _ENDIANNESS = 302,
      _NOFILL = 303,
      _FLETCHER32 = 304,
-     DATASETID = 305
+     _NCPROPS = 305,
+     _ISNETCDF4 = 306,
+     _SUPERBLOCK = 307,
+     DATASETID = 308
    };
 #endif
 /* Tokens.  */
@@ -137,14 +140,17 @@
 #define _ENDIANNESS 302
 #define _NOFILL 303
 #define _FLETCHER32 304
-#define DATASETID 305
+#define _NCPROPS 305
+#define _ISNETCDF4 306
+#define _SUPERBLOCK 307
+#define DATASETID 308
 
 
 
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 131 "ncgen.y"
+#line 136 "ncgen.y"
 {
 Symbol* sym;
 unsigned long  size; /* allow for zero size to indicate e.g. UNLIMITED*/
@@ -154,7 +160,7 @@ Datalist*      datalist;
 NCConstant       constant;
 }
 /* Line 1529 of yacc.c.  */
-#line 158 "ncgen.tab.h"
+#line 164 "ncgeny.h"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
