@@ -99,7 +99,7 @@ locate(Symbol* refsym)
 		if(sym != NULL) break;
 		parent = parent->container;
 	    }
-	}		
+	}
 	break;
     case NC_TYPE:
 	if(refsym->is_prefixed) {
@@ -130,7 +130,7 @@ locate(Symbol* refsym)
 	    if(sym == NULL) {
 	        sym = uniquetreelocate(refsym,rootgroup); /* want unique */
 	    }
-	}		
+	}
 	break;
     case NC_VAR:
 	if(refsym->is_prefixed) {
@@ -140,7 +140,7 @@ locate(Symbol* refsym)
 	    Symbol* parent = lookupgroup(refsym->prefix);/*get group for refsym*/
    	    /* search this parent for matching name and type*/
 	    sym = lookupingroup(NC_VAR,refsym->name,parent);
-	}		
+	}
         break;
     case NC_GRP:
 	if(refsym->is_prefixed) {
@@ -150,7 +150,7 @@ locate(Symbol* refsym)
  	    Symbol* parent = lookupgroup(refsym->prefix);/*get group for refsym*/
    	    /* search this parent for matching name and type*/
 	    sym = lookupingroup(NC_GRP,refsym->name,parent);
-	}		
+	}
 	break;
 
     default: PANIC1("locate: bad refsym type: %d",refsym->objectclass);
@@ -163,7 +163,7 @@ locate(Symbol* refsym)
 	    ncname = ncclassname(refsym->objectclass);
 	fdebug("locate: %s: %s -> %s\n",
 		ncname,fullname(refsym),(sym?fullname(sym):"NULL"));
-    }   
+    }
     return sym;
 }
 
@@ -184,7 +184,7 @@ uniquetreelocate(Symbol* refsym, Symbol* root)
 	    if(grp->objectclass == NC_GRP && !grp->ref.is_ref) {
 		Symbol* nextsym = uniquetreelocate(refsym,grp);
 		if(nextsym != NULL) {
-		    if(sym != NULL) return NULL; /* not unique */	
+		    if(sym != NULL) return NULL; /* not unique */
 		    sym = nextsym;
 		}
 	    }
@@ -278,14 +278,14 @@ processtypes(void)
 	    break;
         case NC_VLEN: /* keep if its basetype is primitive*/
 	    if(sym->typ.basetype->subclass == NC_PRIM) keep=1;
-	    break;	    	
+	    break;
 	case NC_COMPOUND: /* keep if all fields are primitive*/
 	    keep=1; /*assume all fields are primitive*/
 	    for(j=0;j<listlength(sym->subnodes);j++) {
 		Symbol* field = (Symbol*)listget(sym->subnodes,j);
 		ASSERT(field->subclass == NC_FIELD);
 		if(field->typ.basetype->subclass != NC_PRIM) {keep=0;break;}
-	    }	  
+	    }
 	    break;
 	default: break;/* ignore*/
 	}
@@ -293,7 +293,7 @@ processtypes(void)
 	    sym->touched = 1;
 	    listpush(sorted,(void*)sym);
 	}
-    }	
+    }
     /* 2. repeated walk to collect level i types*/
     do {
         added=0;
@@ -302,29 +302,29 @@ processtypes(void)
 	    if(sym->touched) continue; /* ignore already processed types*/
 	    keep=0; /* assume not addable yet.*/
 	    switch (sym->subclass) {
-	    case NC_PRIM: 
+	    case NC_PRIM:
 	    case NC_OPAQUE:
 	    case NC_ENUM:
 		PANIC("type re-touched"); /* should never happen*/
 	        break;
             case NC_VLEN: /* keep if its basetype is already processed*/
 	        if(sym->typ.basetype->touched) keep=1;
-	        break;	    	
+	        break;
 	    case NC_COMPOUND: /* keep if all fields are processed*/
 	        keep=1; /*assume all fields are touched*/
 	        for(j=0;j<listlength(sym->subnodes);j++) {
 		    Symbol* field = (Symbol*)listget(sym->subnodes,j);
 		    ASSERT(field->subclass == NC_FIELD);
 		    if(!field->typ.basetype->touched) {keep=1;break;}
-	        }	  
+	        }
 	        break;
-	    default: break;				
+	    default: break;
 	    }
 	    if(keep) {
 		listpush(sorted,(void*)sym);
 		sym->touched = 1;
 		added++;
-	    }	    
+	    }
 	}
     } while(added > 0);
     /* Any untouched type => circular dependency*/
@@ -355,16 +355,16 @@ tagvlentypes(Symbol* tsym)
     int tagged = 0;
     unsigned long j;
     switch (tsym->subclass) {
-        case NC_VLEN: 
+        case NC_VLEN:
 	    tagged = 1;
 	    tagvlentypes(tsym->typ.basetype);
-	    break;	    	
+	    break;
 	case NC_COMPOUND: /* keep if all fields are primitive*/
 	    for(j=0;j<listlength(tsym->subnodes);j++) {
 		Symbol* field = (Symbol*)listget(tsym->subnodes,j);
 		ASSERT(field->subclass == NC_FIELD);
 		if(tagvlentypes(field->typ.basetype)) tagged = 1;
-	    }	  
+	    }
 	    break;
 	default: break;/* ignore*/
     }
@@ -377,7 +377,7 @@ static void
 filltypecodes(void)
 {
     Symbol* sym;
-    for(sym=symlist;sym != NULL;sym = sym->next) {    
+    for(sym=symlist;sym != NULL;sym = sym->next) {
 	if(sym->typ.basetype != NULL && sym->typ.typecode == NC_NAT)
 	    sym->typ.typecode = sym->typ.basetype->typ.typecode;
     }
@@ -397,7 +397,7 @@ processenums(void)
 	    ASSERT(esym->subclass == NC_ECONST);
 	    listpush(enumids,(void*)esym);
 	}
-    }	    
+    }
     /* Convert enum values to match enum type*/
     for(i=0;i<listlength(typdefs);i++) {
 	Symbol* tsym = (Symbol*)listget(typdefs,i);
@@ -410,7 +410,7 @@ processenums(void)
 	    newec.nctype = esym->typ.typecode;
 	    convert1(&esym->typ.econst,&newec);
 	    esym->typ.econst = newec;
-	}	
+	}
     }
 }
 
@@ -540,7 +540,7 @@ findecmatches(char* ident)
 	ec = checkeconst(en,ident);
 	if(ec != NULL)
 	    listpush(matches,ec);
-	/* Second, do the prefix check */	
+	/* Second, do the prefix check */
 	len = strlen(en->name);
 	if(strncmp(ident,en->name,len) == 0) {
 		Symbol *ec;
@@ -555,7 +555,7 @@ findecmatches(char* ident)
 	listfree(matches);
         matches = NULL;
     }
-    return matches;    
+    return matches;
 }
 
 static List*
@@ -633,18 +633,25 @@ computesize(Symbol* tsym)
 		computesize(field);
 		/* alignment of struct is same as alignment of first field*/
 		if(i==0) tsym->typ.alignment = field->typ.alignment;
-	    }	  
+	    }
 	    /* now compute the size of the compound based on*/
 	    /* what user specified*/
 	    offset = 0;
-	    for(i=0;i<listlength(tsym->subnodes);i++) {
-		Symbol* field = (Symbol*)listget(tsym->subnodes,i);
-		/* only support 'c' alignment for now*/
-		int alignment = field->typ.alignment;
-		offset += getpadding(offset,alignment);
-		field->typ.offset = offset;
-		offset += field->typ.size;
+            int largealign = 1;
+            for(i=0;i<listlength(tsym->subnodes);i++) {
+              Symbol* field = (Symbol*)listget(tsym->subnodes,i);
+              /* only support 'c' alignment for now*/
+              int alignment = field->typ.alignment;
+	      int padding = getpadding(offset,alignment);
+              offset += padding;
+              field->typ.offset = offset;
+              offset += field->typ.size;
+              if (alignment > largealign) {
+                largealign = alignment;
+              }
 	    }
+	    tsym->typ.cmpdalign = largealign; /* total structure size alignment */
+            offset += (offset % largealign);
 	    tsym->typ.size = offset;
 	    break;
         case NC_FIELD: /* Compute size assume no unlimited dimensions*/
@@ -691,7 +698,7 @@ processvars(void)
 	        if(usingclassic && j != 0)
 		    semerror(vsym->lineno,"Variable: %s: UNLIMITED must be in first dimension only",fullname(vsym));
 	    }
-	}	
+	}
     }
 }
 
@@ -768,7 +775,7 @@ processattributes(void)
 	    Symbol* asym = (Symbol*)listget(attdefs,j);
 	    if(asym->att.var == NULL)
 		continue; /* ignore globals for now */
-	    if(asym->att.var != vsym) continue;	    
+	    if(asym->att.var != vsym) continue;
             listpush(list,(void*)asym);
 	}
 	vsym->var.attributes = list;
@@ -819,7 +826,7 @@ inferattributetype1(Datasrc* src)
 	    return NC_NAT;
 	}
 	srcnext(src);
-    }	    
+    }
     /* Walk repeatedly to get info for inference (loops could be combined) */
 
     /* Compute: all strings or chars? */
@@ -832,7 +839,7 @@ inferattributetype1(Datasrc* src)
 	else if(con->nctype == NC_CHAR) charcount++;
     }
     if((stringcount+charcount) > 0) {
-        if((stringcount+charcount) < srclen(src)) 
+        if((stringcount+charcount) < srclen(src))
 	    return NC_NAT; /* not all textual */
 	return NC_CHAR;
     }
@@ -871,7 +878,7 @@ inferattributetype1(Datasrc* src)
 	case NC_BYTE :   if(con->value.int8v < 0)   {hasneg = 1;} break;
 	case NC_SHORT:   if(con->value.int16v < 0)  {hasneg = 1;} break;
 	case NC_INT:     if(con->value.int32v < 0)  {hasneg = 1;} break;
-	}	
+	}
     }
 
     /* Compute: inferred integer type */
@@ -879,7 +886,7 @@ inferattributetype1(Datasrc* src)
     result = NC_NAT;
     while(srcmore(src)) {
 	NCConstant* con = srcnext(src);
-	result = infertype(result,con->nctype,hasneg);	
+	result = infertype(result,con->nctype,hasneg);
 	if(result == NC_NAT) break; /* something wrong */
     }
     return result;
@@ -899,7 +906,7 @@ inferattributetype(Symbol* asym)
 	return;
     }
     src = datalist2src(datalist);
-    nctype = inferattributetype1(src);    
+    nctype = inferattributetype1(src);
     freedatasrc(src);
     if(nctype == NC_NAT) { /* Illegal attribute value list */
 	semerror(asym->lineno,"Non-simple list of values for untyped attribute: %s",fullname(asym));
@@ -946,10 +953,9 @@ validateNIL(Symbol* sym)
 {
 #ifdef USE_NETCDF4
     Datalist* datalist = sym->data;
-
-    if(sym->data == NULL || datalist->length == 0) return;
+    if(datalist == NULL || datalist->length == 0) return;
     if(sym->typ.typecode == NC_STRING) return;
-    validateNILr(sym->data);
+    validateNILr(datalist);
 #endif
 }
 
@@ -1080,7 +1086,7 @@ computeunlimitedsizes(Dimset* dimset, int dimindex, Datalist* data, int ischar)
     int nextunlim,lastunlim;
     Symbol* thisunlim = dimset->dimsyms[dimindex];
     size_t length;
-    
+
     ASSERT(thisunlim->dim.isunlimited);
     nextunlim = findunlimited(dimset,dimindex+1);
     lastunlim = (nextunlim == dimset->ndims);
